@@ -23,6 +23,7 @@ describe 'glance::api' do
       :purge_config                   => false,
       :delayed_delete                 => '<SERVICE DEFAULT>',
       :scrub_time                     => '<SERVICE DEFAULT>',
+      :enforce_secure_rbac            => '<SERVICE DEFAULT>',
       :image_cache_dir                => '/var/lib/glance/image-cache',
       :image_import_plugins           => '<SERVICE DEFAULT>',
       :image_conversion_output_format => '<SERVICE DEFAULT>',
@@ -65,6 +66,7 @@ describe 'glance::api' do
         :location_strategy              => 'store_type',
         :delayed_delete                 => 'true',
         :scrub_time                     => '10',
+        :enforce_secure_rbac            => 'true',
         :image_cache_dir                => '/tmp/glance',
         :image_import_plugins           => 'image_conversion',
         :image_conversion_output_format => 'raw',
@@ -125,6 +127,7 @@ describe 'glance::api' do
             'location_strategy',
             'delayed_delete',
             'scrub_time',
+            'enforce_secure_rbac',
             'image_cache_dir',
             'image_cache_stall_time',
             'image_cache_max_size',
@@ -262,6 +265,22 @@ describe 'glance::api' do
       end
     end
 
+    describe 'with platform default oslo concurrency lock_path' do
+      it { is_expected.to contain_oslo__concurrency('glance_api_config').with(
+        :lock_path => platform_params[:lock_path]
+      )}
+    end
+
+    describe 'with overridden oslo concurrency lock_path' do
+      let :params do
+        {:lock_path => '/glance/lock/path' }
+      end
+
+      it { is_expected.to contain_oslo__concurrency('glance_api_config').with(
+        :lock_path => '/glance/lock/path',
+      )}
+    end
+
     describe 'setting enable_proxy_headers_parsing' do
       let :params do
         default_params.merge({:enable_proxy_headers_parsing => true })
@@ -540,6 +559,15 @@ describe 'glance::api' do
         facts.merge!(OSDefaults.get_facts())
       end
 
+      let(:platform_params) do
+        case facts[:osfamily]
+        when 'Debian'
+          { :lock_path => '/var/lock/glance' }
+        when 'RedHat'
+          { :lock_path => '/var/lib/glance/tmp' }
+        end
+      end
+
       it_configures 'glance::api'
       it_configures "glance::api #{facts[:osfamily]}"
     end
